@@ -14,6 +14,7 @@
 #include "cut-test-suite.h"
 #include "cut-test-result.h"
 #include "cut-ui.h"
+#include "cut-contractor.h"
 #include "cut-factory-builder.h"
 #include "cut-report-factory-builder.h"
 #include "cut-ui-factory-builder.h"
@@ -40,6 +41,21 @@ cut_test_result_status_get_type (void)
   return etype;
 }
 GType
+cut_order_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { CUT_ORDER_NONE_SPECIFIED, "CUT_ORDER_NONE_SPECIFIED", "none-specified" },
+      { CUT_ORDER_NAME_ASCENDING, "CUT_ORDER_NAME_ASCENDING", "name-ascending" },
+      { CUT_ORDER_NAME_DESCENDING, "CUT_ORDER_NAME_DESCENDING", "name-descending" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("CutOrder", values);
+  }
+  return etype;
+}
+GType
 cut_report_file_mode_get_type (void)
 {
   static GType etype = 0;
