@@ -45,12 +45,44 @@ static gchar *test_directory = NULL;
 static gchar *source_directory = NULL;
 static const gchar **test_case_names = NULL;
 static const gchar **test_names = NULL;
+static CutOrder test_case_order = CUT_ORDER_NONE_SPECIFIED;
 static gboolean use_multi_thread = FALSE;
-static gboolean _show_all_uis = FALSE;
 static GList *factories = NULL;
 
+static gboolean
+print_version (const gchar *option_name, const gchar *value,
+               gpointer data, GError **error)
+{
+    g_print("%s\n", VERSION);
+    exit(0);
+    return TRUE;
+}
+
+static gboolean
+parse_test_case_order (const gchar *option_name, const gchar *value,
+                       gpointer data, GError **error)
+{
+    if (g_utf8_collate(value, "none") == 0) {
+        test_case_order = CUT_ORDER_NONE_SPECIFIED;
+    } else if (g_utf8_collate(value, "name") == 0) {
+        test_case_order = CUT_ORDER_NAME_ASCENDING;
+    } else if (g_utf8_collate(value, "name-desc") == 0) {
+        test_case_order = CUT_ORDER_NAME_DESCENDING;
+    } else {
+        g_set_error(error,
+                    G_OPTION_ERROR,
+                    G_OPTION_ERROR_BAD_VALUE,
+                    _("Invalid test case order value: %s"), value);
+        return FALSE;
+    }
+
+    return TRUE;
+}
+
 static const GOptionEntry option_entries[] =
 {
+    {"version", 0, 0, G_OPTION_ARG_CALLBACK, print_version,
+     N_("Show version"), NULL},
     {"source-directory", 's', 0, G_OPTION_ARG_STRING, &source_directory,
      N_("Set directory of source code"), "DIRECTORY"},
     {"name", 'n', 0, G_OPTION_ARG_STRING_ARRAY, &test_names,
@@ -59,29 +91,11 @@ static const GOptionEntry option_entries[] =
      N_("Specify test cases"), "TEST_CASE_NAME"},
     {"multi-thread", 'm', 0, G_OPTION_ARG_NONE, &use_multi_thread,
      N_("Run test cases with multi-thread"), NULL},
-    {"show-all-uis", 0, 0, G_OPTION_ARG_NONE, &_show_all_uis,
-     N_("Show all available UIs and exit"), NULL},
+    {"test-case-order", 0, 0, G_OPTION_ARG_CALLBACK, parse_test_case_order,
+     N_("Sort test case by. Default is 'none'."), "[none|name|name-desc]"},
     {NULL}
 };
 
-static void
-show_all_uis (void)
-{
-    GList *names, *node;
-
-    names = cut_module_factory_get_names("ui");
-    for (node = names; node; node = g_list_next(node)) {
-        const gchar *name = node->data;
-        if (g_list_next(node))
-            g_print("%s, ", name);
-        else
-            g_print("%s", name);
-    }
-    g_print("\n");
-    g_list_foreach(names, (GFunc)g_free, NULL);
-    g_list_free(names);
-}
-
 void
 cut_init (int *argc, char ***argv)
 {
@@ -109,23 +123,11 @@ cut_init (int *argc, char ***argv)
     g_option_context_add_main_entries(option_context, option_entries, "cutter");
     g_option_context_set_help_enabled(option_context, FALSE);
     g_option_context_set_ignore_unknown_options(option_context, TRUE);
-    if (!g_option_context_parse(option_context, argc, argv, &error)) {
-        g_print("%s\n", error->message);
-        g_error_free(error);
-        g_option_context_free(option_context);
-        exit(1);
-    }
 
     cut_module_factory_init();
     cut_module_factory_load(NULL);
     cut_module_factory_set_option_context(option_context);
-    if (_show_all_uis) {
-        show_all_uis();
-        exit(1);
-    }
 
-    g_option_context_set_help_enabled(option_context, TRUE);
-    g_option_context_set_ignore_unknown_options(option_context, TRUE);
     if (!g_option_context_parse(option_context, argc, argv, &error)) {
         g_print("%s\n", error->message);
         g_error_free(error);
@@ -133,6 +135,7 @@ cut_init (int *argc, char ***argv)
         exit(1);
     }
 
+
     factories = cut_module_factory_build_factories();
 
     g_option_context_set_help_enabled(option_context, TRUE);
@@ -194,6 +197,7 @@ cut_create_runner (void)
     cut_runner_set_multi_thread(runner, use_multi_thread);
     cut_runner_set_target_test_case_names(runner, test_case_names);
     cut_runner_set_target_test_names(runner, test_names);
+    cut_runner_set_test_case_order(runner, test_case_order);
 
     return runner;
 }
