@@ -30,16 +30,17 @@
 #include "cut-report-factory-builder.h"
 #include "cut-module-factory.h"
 
-static const gchar **filenames;
+static const gchar *xml_report;
 static CutReportFactoryBuilder *the_builder = NULL;
 
 static GObject *constructor  (GType                  type,
                               guint                  n_props,
                               GObjectConstructParam *props);
 
-static void   set_option_context (CutFactoryBuilder *builder,
-                                  GOptionContext    *context);
-static GList *build              (CutFactoryBuilder *builder);
+static void         set_option_context (CutFactoryBuilder *builder,
+                                        GOptionContext    *context);
+static GList       *build              (CutFactoryBuilder *builder);
+static const gchar *get_type_name      (CutFactoryBuilder *builder);
 
 G_DEFINE_TYPE(CutReportFactoryBuilder, cut_report_factory_builder, CUT_TYPE_FACTORY_BUILDER)
 
@@ -56,6 +57,7 @@ cut_report_factory_builder_class_init (CutReportFactoryBuilderClass *klass)
 
     builder_class->set_option_context = set_option_context;
     builder_class->build              = build;
+    builder_class->get_type_name      = get_type_name;
 }
 
 static GObject *
@@ -76,58 +78,66 @@ constructor (GType type, guint n_props, GObjectConstructParam *props)
 static void
 cut_report_factory_builder_init (CutReportFactoryBuilder *builder)
 {
+    const gchar *dir;
+
+    dir = g_getenv("CUT_REPORT_FACTORY_MODULE_DIR");
+    if (!dir)
+        dir = REPORT_FACTORY_MODULEDIR;
+
+    g_object_set(G_OBJECT(builder),
+                 "module-dir", dir,
+                 NULL);
 }
 
 static void
 set_option_context (CutFactoryBuilder *builder, GOptionContext *context)
 {
+    GOptionGroup *group;
     GOptionEntry entries[] = {
-        {"output-files", 'o', 0, G_OPTION_ARG_STRING_ARRAY, &filenames,
-         N_("Set filenames of the report"), "OUTPUT_FILENAME"},
+        {"xml-report", 0, 0, G_OPTION_ARG_STRING, &xml_report,
+         N_("Set filename of XML report"), "FILE"},
         {NULL}
     };
 
-    g_option_context_add_main_entries(context, entries, NULL);
+    group = g_option_group_new(("report"),
+                               _("Report Options"),
+                               _("Show report options"),
+                               builder, NULL);
+    g_option_group_add_entries(group, entries);
+    g_option_group_set_translation_domain(group, GETTEXT_PACKAGE);
+    g_option_context_add_group(context, group);
 }
 
 static GList *
 build (CutFactoryBuilder *builder)
 {
+    const gchar *report_type;
     GList *factories = NULL;
 
-    if (!filenames || !*filenames)
+    if (!xml_report)
         return NULL;
 
-    while (*filenames) {
-        gchar *basename, *type;
+    report_type = "xml";
+    if (cut_module_factory_exist_module("report", report_type)) {
         CutModuleFactory *module_factory;
-
-        basename = g_path_get_basename(*filenames);
-        if (!strchr(basename, '.')) {
-            g_free(basename);
-            continue; /* skip unspecified type */
-        }
-
-        type = g_strdup(strrchr(basename, '.'));
-        if (cut_module_factory_exist_module("report", type)) {
-            GOptionContext *option_context;
-            module_factory = cut_module_factory_new("report", type, NULL);
-            g_object_get(builder,
-                         "option-context", &option_context,
-                         NULL);
-            cut_module_factory_set_option_group(module_factory,
-                                                option_context);
-            factories = g_list_prepend(factories, module_factory);
-        }
-
-        g_free(type);
-        g_free(basename);
-        filenames++;
+        GOptionContext *option_context;
+        module_factory = cut_module_factory_new("report", report_type,
+                                                "filename", xml_report,
+                                                NULL);
+        g_object_get(builder, "option-context", &option_context, NULL);
+        cut_module_factory_set_option_group(module_factory, option_context);
+        factories = g_list_prepend(factories, module_factory);
     }
 
     return factories;
 }
 
+const gchar *
+get_type_name (CutFactoryBuilder *builder)
+{
+    return "report";
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
