@@ -52,7 +52,7 @@ GType        cut_test_container_get_type     (void) G_GNUC_CONST;
 
 void         cut_test_container_add_test     (CutTestContainer *container,
                                               CutTest          *test);
-const GList *cut_test_container_get_children (CutTestContainer *container);
+GList       *cut_test_container_get_children (CutTestContainer *container);
 GList       *cut_test_container_filter_children
                                              (CutTestContainer *container,
                                               const gchar **filter);
