@@ -309,32 +309,6 @@ cut_test_context_pass_assertion (CutTestContext *context)
     g_signal_emit_by_name(priv->test, "pass-assertion", context);
 }
 
-static const gchar *
-status_to_signal_name (CutTestResultStatus status)
-{
-    const gchar *status_signal_name = "success";
-
-    switch (status) {
-      case CUT_TEST_RESULT_FAILURE:
-        status_signal_name = "failure";
-        break;
-      case CUT_TEST_RESULT_ERROR:
-        status_signal_name = "error";
-        break;
-      case CUT_TEST_RESULT_PENDING:
-        status_signal_name = "pending";
-        break;
-      case CUT_TEST_RESULT_NOTIFICATION:
-        status_signal_name = "notification";
-        break;
-      default:
-        g_assert("must not happen");
-        break;
-    }
-
-    return status_signal_name;
-}
-
 void
 cut_test_context_register_result (CutTestContext *context,
                                   CutTestResultStatus status,
@@ -347,22 +321,17 @@ cut_test_context_register_result (CutTestContext *context,
     CutTestContextPrivate *priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
     CutTestResult *result;
     const gchar *status_signal_name = NULL;
-    gchar *user_message = NULL, *system_message = NULL;
-    const gchar *format;
+    const gchar *system_message;
+    gchar *user_message = NULL, *user_message_format;
     va_list args;
 
     priv->failed = TRUE;
 
+    system_message = message;
     va_start(args, message);
-    if (message) {
-        system_message = g_strdup_vprintf(message, args);
-    }
-    while (message) {
-        message = va_arg(args, gchar *); /* FIXME */
-    }
-    format = va_arg(args, gchar *);
-    if (format) {
-        user_message = g_strdup_vprintf(format, args);
+    user_message_format = va_arg(args, gchar *);
+    if (user_message_format) {
+        user_message = g_strdup_vprintf(user_message_format, args);
     }
     va_end(args);
 
@@ -370,12 +339,10 @@ cut_test_context_register_result (CutTestContext *context,
                                  priv->test, priv->test_case, priv->test_suite,
                                  user_message, system_message,
                                  function_name, filename, line);
-    if (system_message)
-        g_free(system_message);
     if (user_message)
         g_free(user_message);
 
-    status_signal_name = status_to_signal_name(status);
+    status_signal_name = cut_test_result_status_to_signal_name(status);
     if (priv->test) {
         cut_test_stop_timer(priv->test);
         g_object_set(result, "elapsed", cut_test_get_elapsed(priv->test), NULL);
@@ -409,6 +376,23 @@ cut_test_context_take_string (CutTestContext *context,
     return taken_string;
 }
 
+const char *
+cut_test_context_take_printf (CutTestContext *context, char *format, ...)
+{
+    const char *taken_string = NULL;
+    va_list args;
+
+    va_start(args, format);
+    if (format) {
+        char *formatted_string;
+        formatted_string = g_strdup_vprintf(format, args);
+        taken_string = cut_test_context_take_string(context, formatted_string);
+    }
+    va_end(args);
+
+    return taken_string;
+}
+
 const char *
 cut_test_context_inspect_string_array (CutTestContext *context,
                                        const char    **strings)
