@@ -91,7 +91,7 @@ cut_test_suite_class_init (CutTestSuiteClass *klass)
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
 
-	cut_test_suite_signals[READY_SIGNAL]
+    cut_test_suite_signals[READY_SIGNAL]
         = g_signal_new("ready",
                        G_TYPE_FROM_CLASS(klass),
                        G_SIGNAL_RUN_LAST,
@@ -100,23 +100,23 @@ cut_test_suite_class_init (CutTestSuiteClass *klass)
                        _cut_marshal_VOID__UINT_UINT,
                        G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_UINT);
 
-	cut_test_suite_signals[START_TEST_CASE_SIGNAL]
+    cut_test_suite_signals[START_TEST_CASE_SIGNAL]
         = g_signal_new("start-test-case",
-                G_TYPE_FROM_CLASS(klass),
-                G_SIGNAL_RUN_LAST,
-                G_STRUCT_OFFSET(CutTestSuiteClass, start_test_case),
-                NULL, NULL,
-                g_cclosure_marshal_VOID__OBJECT,
-                G_TYPE_NONE, 1, CUT_TYPE_TEST_CASE);
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutTestSuiteClass, start_test_case),
+                       NULL, NULL,
+                       g_cclosure_marshal_VOID__OBJECT,
+                       G_TYPE_NONE, 1, CUT_TYPE_TEST_CASE);
 
-	cut_test_suite_signals[COMPLETE_TEST_CASE_SIGNAL]
+    cut_test_suite_signals[COMPLETE_TEST_CASE_SIGNAL]
         = g_signal_new("complete-test-case",
-                G_TYPE_FROM_CLASS(klass),
-                G_SIGNAL_RUN_LAST,
-                G_STRUCT_OFFSET(CutTestSuiteClass, complete_test_case),
-                NULL, NULL,
-                g_cclosure_marshal_VOID__OBJECT,
-                G_TYPE_NONE, 1, CUT_TYPE_TEST_CASE);
+                       G_TYPE_FROM_CLASS(klass),
+                       G_SIGNAL_RUN_LAST,
+                       G_STRUCT_OFFSET(CutTestSuiteClass, complete_test_case),
+                       NULL, NULL,
+                       g_cclosure_marshal_VOID__OBJECT,
+                       G_TYPE_NONE, 1, CUT_TYPE_TEST_CASE);
 }
 
 static void
@@ -293,7 +293,7 @@ collect_stack_trace (void)
 }
 
 static void
-ill_be_back_handler (int signum)
+i_will_be_back_handler (int signum)
 {
     g_free(stack_trace);
     stack_trace = NULL;
@@ -302,10 +302,10 @@ ill_be_back_handler (int signum)
 }
 
 static void
-emit_ready_signal (CutTestSuite *test_suite, const GList *test_cases,
+emit_ready_signal (CutTestSuite *test_suite, GList *test_cases,
                    const gchar **test_names)
 {
-    const GList *node;
+    GList *node;
     guint n_test_cases, n_tests;
 
     n_test_cases = 0;
@@ -323,27 +323,29 @@ emit_ready_signal (CutTestSuite *test_suite, const GList *test_cases,
 
 static gboolean
 cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
-                               const GList *test_cases, const gchar **test_names)
+                               GList *test_cases, const gchar **test_names)
 {
-    const GList *list;
     GList *node, *threads = NULL;
+    GList *sorted_test_cases;
     gboolean try_thread;
     gboolean all_success = TRUE;
     gint signum;
     sighandler_t previous_segv_handler, previous_int_handler;
 
-    previous_segv_handler = signal(SIGSEGV, ill_be_back_handler);
-    previous_int_handler = signal(SIGINT, ill_be_back_handler);
+    sorted_test_cases = g_list_copy(test_cases);
+    sorted_test_cases = cut_runner_sort_test_cases(runner, sorted_test_cases);
+    previous_segv_handler = signal(SIGSEGV, i_will_be_back_handler);
+    previous_int_handler = signal(SIGINT, i_will_be_back_handler);
     signum = setjmp(jump_buffer);
     switch (signum) {
       case 0:
         cut_runner_start_test_suite(runner, test_suite);
-        emit_ready_signal(test_suite, test_cases, test_names);
+        emit_ready_signal(test_suite, sorted_test_cases, test_names);
         g_signal_emit_by_name(CUT_TEST(test_suite), "start");
 
         try_thread = cut_runner_get_multi_thread(runner);
-        for (list = test_cases; list; list = g_list_next(list)) {
-            CutTestCase *test_case = list->data;
+        for (node = sorted_test_cases; node; node = g_list_next(node)) {
+            CutTestCase *test_case = node->data;
 
             if (!test_case)
                 continue;
@@ -368,9 +370,9 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
                                          NULL,
                                          NULL,
                                          test_suite,
-                                         NULL, NULL, 
+                                         NULL, NULL,
                                          NULL, NULL, 0);
-            g_signal_emit_by_name(CUT_TEST(test_suite), "success", result);
+            g_signal_emit_by_name(CUT_TEST(test_suite), "success", NULL, result);
             g_object_unref(result);
         }
         break;
@@ -387,6 +389,8 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
 
     g_signal_emit_by_name(CUT_TEST(test_suite), "complete");
 
+    g_list_free(sorted_test_cases);
+
     return all_success;
 }
 
@@ -419,7 +423,7 @@ gboolean
 cut_test_suite_run_test (CutTestSuite *suite, CutRunner *runner,
                          const gchar *test_name)
 {
-    const GList *test_cases;
+    GList *test_cases;
     const gchar *test_names[] = {NULL, NULL};
 
     g_return_val_if_fail(CUT_IS_TEST_SUITE(suite), FALSE);
@@ -469,11 +473,12 @@ cut_test_suite_run_with_filter (CutTestSuite *test_suite,
                                                default_test_case_names);
     }
 
+    if (!filtered_test_cases)
+        return success;
+
     success = cut_test_suite_run_test_cases(test_suite, runner,
                                             filtered_test_cases, test_names);
-
-    if (filtered_test_cases)
-        g_list_free(filtered_test_cases);
+    g_list_free(filtered_test_cases);
 
     return success;
 }
