@@ -36,9 +36,10 @@ static GObject *constructor  (GType                  type,
                               guint                  n_props,
                               GObjectConstructParam *props);
 
-static void   set_option_context (CutFactoryBuilder *builder,
-                                  GOptionContext    *context);
-static GList *build              (CutFactoryBuilder *builder);
+static void         set_option_context (CutFactoryBuilder *builder,
+                                        GOptionContext    *context);
+static GList       *build              (CutFactoryBuilder *builder);
+static const gchar *get_type_name      (CutFactoryBuilder *builder);
 
 G_DEFINE_TYPE(CutUIFactoryBuilder, cut_ui_factory_builder, CUT_TYPE_FACTORY_BUILDER)
 
@@ -55,6 +56,7 @@ cut_ui_factory_builder_class_init (CutUIFactoryBuilderClass *klass)
 
     builder_class->set_option_context = set_option_context;
     builder_class->build              = build;
+    builder_class->get_type_name      = get_type_name;
 }
 
 static GObject *
@@ -75,18 +77,55 @@ constructor (GType type, guint n_props, GObjectConstructParam *props)
 static void
 cut_ui_factory_builder_init (CutUIFactoryBuilder *builder)
 {
+    const gchar *dir;
+
+    dir = g_getenv("CUT_UI_FACTORY_MODULE_DIR");
+    if (!dir)
+        dir = UI_FACTORY_MODULEDIR;
+
+    g_object_set(G_OBJECT(builder),
+                 "module-dir", dir,
+                 NULL);
 }
 
 static void
 set_option_context (CutFactoryBuilder *builder, GOptionContext *context)
 {
+    static gchar *arg_description = NULL;
+    GOptionGroup *group;
     GOptionEntry entries[] = {
         {"ui", 'u', 0, G_OPTION_ARG_STRING, &ui_name,
-         N_("Specify UI"), "[console|gtk]"},
+         N_("Specify UI"), NULL},
         {NULL}
     };
 
-    g_option_context_add_main_entries(context, entries, NULL);
+    if (!arg_description) {
+        GString *available_uis;
+        GList *names, *node;
+
+        available_uis = g_string_new("[");
+        names = cut_module_factory_get_names("ui");
+        for (node = names; node; node = g_list_next(node)) {
+            const gchar *name = node->data;
+            g_string_append(available_uis, name);
+            if (g_list_next(node))
+                g_string_append(available_uis, "|");
+        }
+        g_string_append(available_uis, "]");
+        arg_description = g_string_free(available_uis, FALSE);
+
+        g_list_foreach(names, (GFunc)g_free, NULL);
+        g_list_free(names);
+    }
+    entries[0].arg_description = arg_description;
+
+    group = g_option_group_new(("ui"),
+                               _("UI Options"),
+                               _("Show UI options"),
+                               builder, NULL);
+    g_option_group_add_entries(group, entries);
+    g_option_group_set_translation_domain(group, GETTEXT_PACKAGE);
+    g_option_context_add_group(context, group);
 }
 
 static GList *
@@ -112,6 +151,12 @@ build (CutFactoryBuilder *builder)
     return factories;
 }
 
+const gchar *
+get_type_name (CutFactoryBuilder *builder)
+{
+    return "ui";
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
