@@ -23,30 +23,14 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <stdlib.h>
-#include <string.h>
 #include <glib.h>
-#include <glib/gstdio.h>
 
 #include "cut-ui.h"
-#include "cut-runner.h"
-#include "cut-test.h"
-#include "cut-test-case.h"
 #include "cut-module.h"
 
 static GList *uis = NULL;
 static gchar *module_dir = NULL;
 
-static void dispose        (GObject         *object);
-static void set_property   (GObject         *object,
-                            guint            prop_id,
-                            const GValue    *value,
-                            GParamSpec      *pspec);
-static void get_property   (GObject         *object,
-                            guint            prop_id,
-                            GValue          *value,
-                            GParamSpec      *pspec);
-
 void cut_ui_init (void)
 {
 }
@@ -139,19 +123,18 @@ cut_ui_get_log_domains (void)
 }
 
 #define cut_ui_init init
-G_DEFINE_ABSTRACT_TYPE (CutUI, cut_ui, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE (CutUI, cut_ui, CUT_TYPE_LISTENER)
 #undef cut_ui_init
 
 static void
 cut_ui_class_init (CutUIClass *klass)
 {
-    GObjectClass *gobject_class;
+    CutListenerClass *listener_class;
 
-    gobject_class = G_OBJECT_CLASS(klass);
+    listener_class = CUT_LISTENER_CLASS(klass);
 
-    gobject_class->dispose      = dispose;
-    gobject_class->set_property = set_property;
-    gobject_class->get_property = get_property;
+    listener_class->attach_to_runner   = NULL;
+    listener_class->detach_from_runner = NULL;
 }
 
 static void
@@ -159,37 +142,6 @@ init (CutUI *ui)
 {
 }
 
-static void
-dispose (GObject *object)
-{
-}
-
-static void
-set_property (GObject      *object,
-              guint         prop_id,
-              const GValue *value,
-              GParamSpec   *pspec)
-{
-    switch (prop_id) {
-      default:
-        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
-        break;
-    }
-}
-
-static void
-get_property (GObject    *object,
-              guint       prop_id,
-              GValue     *value,
-              GParamSpec *pspec)
-{
-    switch (prop_id) {
-      default:
-        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
-        break;
-    }
-}
-
 CutUI *
 cut_ui_new (const gchar *name, const gchar *first_property, ...)
 {
@@ -207,20 +159,6 @@ cut_ui_new (const gchar *name, const gchar *first_property, ...)
     return CUT_UI(ui);
 }
 
-gboolean
-cut_ui_run (CutUI *ui, CutRunner *runner)
-{
-    CutUIClass *klass;
-
-    g_return_val_if_fail(CUT_IS_UI(ui), FALSE);
-
-    klass = CUT_UI_GET_CLASS(ui);
-    if (klass->run)
-        return klass->run(ui, runner);
-    else
-        return FALSE;
-}
-
 /*
 vi:nowrap:ai:expandtab:sw=4
 */
