@@ -27,6 +27,7 @@
 #include <string.h>
 #include <glib.h>
 #include <glib/gi18n-lib.h>
+#include <glib/gstdio.h>
 #include <gmodule.h>
 
 #include <cutter/cut-module-impl.h>
@@ -240,10 +241,47 @@ get_property (GObject    *object,
     }
 }
 
+static void
+output_to_file (CutReportXML *report, gchar *string)
+{
+    const gchar *filename;
+    FILE *fp;
+
+    if (!string)
+        return;
+
+    filename = cut_report_get_filename(CUT_REPORT(report));
+    if (!filename)
+        return;
+
+    fp = g_fopen(filename, "a");
+    if (!fp)
+        return;
+
+    fwrite(string, strlen(string), 1, fp);
+
+    fclose(fp);
+}
+
+static void
+cb_ready_test_suite (CutRunner *runner, CutTestSuite *test_suite,
+                     guint n_test_cases, guint n_tests,
+                     CutReportXML *report)
+{
+    const gchar *filename;
+
+    filename = cut_report_get_filename(CUT_REPORT(report));
+    if (!filename)
+        return;
+    if (g_file_test(filename, G_FILE_TEST_EXISTS))
+        g_unlink(filename);
+}
+
 static void
 cb_start_test_suite (CutRunner *runner, CutTestSuite *test_suite,
                      CutReportXML *report)
 {
+    output_to_file(report, "<report>\n");
 }
 
 static void
@@ -259,44 +297,16 @@ cb_start_test (CutRunner *runner, CutTest *test, CutTestContext *test_context,
 }
 
 static void
-cb_success_test (CutRunner *runner, CutTest *test, CutReportXML *report)
-{
-}
-
-static void
-cb_failure_test (CutRunner      *runner,
-                 CutTest        *test,
-                 CutTestContext *test_context,
-                 CutTestResult  *result,
-                 CutReportXML   *report)
-{
-}
-
-static void
-cb_error_test (CutRunner      *runner,
-               CutTest        *test,
-               CutTestContext *test_context,
-               CutTestResult  *result,
-               CutReportXML   *report)
-{
-}
-
-static void
-cb_pending_test (CutRunner      *runner,
-                 CutTest        *test,
-                 CutTestContext *test_context,
-                 CutTestResult  *result,
-                 CutReportXML   *report)
-{
-}
-
-static void
-cb_notification_test (CutRunner      *runner,
-                      CutTest        *test,
-                      CutTestContext *test_context,
-                      CutTestResult  *result,
-                      CutReportXML   *report)
+cb_test_signal (CutRunner      *runner,
+                CutTest        *test,
+                CutTestContext *test_context,
+                CutTestResult  *result,
+                CutReportXML   *report)
 {
+    gchar *string;
+    string = get_result(result);
+    output_to_file(report, string);
+    g_free(string);
 }
 
 static void
@@ -315,6 +325,7 @@ static void
 cb_complete_test_suite (CutRunner *runner, CutTestSuite *test_suite,
                         CutReportXML *report)
 {
+    output_to_file(report, "</report>");
 }
 
 static void
@@ -329,15 +340,19 @@ connect_to_runner (CutReportXML *report, CutRunner *runner)
 #define CONNECT(name) \
     g_signal_connect(runner, #name, G_CALLBACK(cb_ ## name), report)
 
+#define CONNECT_TO_TEST(name) \
+    g_signal_connect(runner, #name, G_CALLBACK(cb_test_signal), report)
+
+    CONNECT(ready_test_suite);
     CONNECT(start_test_suite);
     CONNECT(start_test_case);
     CONNECT(start_test);
 
-    CONNECT(success_test);
-    CONNECT(failure_test);
-    CONNECT(error_test);
-    CONNECT(pending_test);
-    CONNECT(notification_test);
+    CONNECT_TO_TEST(success_test);
+    CONNECT_TO_TEST(failure_test);
+    CONNECT_TO_TEST(error_test);
+    CONNECT_TO_TEST(pending_test);
+    CONNECT_TO_TEST(notification_test);
 
     CONNECT(complete_test);
     CONNECT(complete_test_case);
@@ -360,18 +375,16 @@ disconnect_from_runner (CutReportXML *report, CutRunner *runner)
     DISCONNECT(start_test_case);
     DISCONNECT(start_test);
 
-    DISCONNECT(success_test);
-    DISCONNECT(failure_test);
-    DISCONNECT(error_test);
-    DISCONNECT(pending_test);
-    DISCONNECT(notification_test);
-
     DISCONNECT(complete_test);
     DISCONNECT(complete_test_case);
     DISCONNECT(complete_test_suite);
 
     DISCONNECT(crashed);
 
+    g_signal_handlers_disconnect_by_func(runner,
+                                         G_CALLBACK(cb_test_signal),
+                                         report);
+
 #undef DISCONNECT
 }
 
@@ -455,7 +468,7 @@ append_element_with_value (GString *string, guint indent, const gchar *element_n
 {
     gchar *escaped;
     append_indent(string, indent);
-    escaped = g_markup_printf_escaped("<%s>%s</%s>\n", 
+    escaped = g_markup_printf_escaped("<%s>%s</%s>\n",
                                       element_name,
                                       value,
                                       element_name);
@@ -466,20 +479,21 @@ append_element_with_value (GString *string, guint indent, const gchar *element_n
 static void
 append_element_valist (GString *string, guint indent, const gchar *element_name, va_list var_args)
 {
-  	const gchar *name;
-  
-  	name = element_name;
-  
-  	while (name) {
-		const gchar *value = va_arg(var_args, gchar*);
+    const gchar *name;
+
+    name = element_name;
+
+    while (name) {
+        const gchar *value = va_arg(var_args, gchar *);
         if (value)
             append_element_with_value(string, indent, name, value);
-		name = va_arg(var_args, gchar*);
+        name = va_arg(var_args, gchar *);
     }
 }
 
 static void
-append_element_with_children (GString *string, guint indent, const gchar *element_name, 
+append_element_with_children (GString *string, guint indent,
+                              const gchar *element_name,
                               const gchar *first_child_element, ...)
 {
     gchar *escaped;
@@ -524,6 +538,9 @@ append_test_info_to_string (GString *string, const gchar *element_name, CutTest
     guint indent = 4;
     GHashTable *attributes;
 
+    if (!test)
+        return;
+
     escaped = g_markup_escape_text(element_name, -1);
     append_indent(string, indent);
     g_string_append_printf(string, "<%s>\n", escaped);
@@ -536,7 +553,7 @@ append_test_info_to_string (GString *string, const gchar *element_name, CutTest
     if (description)
         append_element_with_value(string, indent + 2, "description", description);
 
-    attributes = (GHashTable*)cut_test_get_attributes(test);
+    attributes = (GHashTable *)cut_test_get_attributes(test);
     if (attributes)
         g_hash_table_foreach(attributes, (GHFunc)append_attribute, string);
 
@@ -588,7 +605,8 @@ get_result (CutTestResult *result)
     GString *xml = g_string_new("");
 
     g_string_append(xml, "  <result>\n");
-    append_test_info_to_string(xml, "test-case", CUT_TEST(cut_test_result_get_test_case(result)));
+    append_test_info_to_string(xml, "test-case",
+                               CUT_TEST(cut_test_result_get_test_case(result)));
     append_test_info_to_string(xml, "test", cut_test_result_get_test(result));
     append_test_result_to_string(xml, result);
     g_string_append(xml, "  </result>\n");
