@@ -384,14 +384,16 @@ cb_start_test (CutRunner *runner, CutTest *test, CutTestContext *test_context,
 }
 
 static void
-cb_success_test (CutRunner *runner, CutTest *test, CutUIConsole *console)
+cb_success_test (CutRunner      *runner,
+                 CutTest        *test,
+                 CutTestContext *context,
+                 CutTestResult  *result,
+                 CutUIConsole   *console)
 {
     if (console->verbose_level < CUT_VERBOSE_LEVEL_NORMAL)
         return;
-    if (!CUT_IS_TEST_CONTAINER(test)) {
-        print_for_status(console, CUT_TEST_RESULT_SUCCESS, ".");
-        fflush(stdout);
-    }
+    print_for_status(console, CUT_TEST_RESULT_SUCCESS, ".");
+    fflush(stdout);
 }
 
 static void
