@@ -7,6 +7,9 @@ if test x"$NO_MAKE" != x"yes"; then
 fi
 
 export CUT_UI_MODULE_DIR=$BASE_DIR/../../cutter/module/ui/.libs
-export CUT_UI_FACTORY_MODULE_DIR=$BASE_DIR/../../cutter/module/ui-factory/.libs
+export CUT_REPORT_MODULE_DIR=$BASE_DIR/../../cutter/module/report/.libs
+export CUT_REPORT_FACTORY_MODULE_DIR=$BASE_DIR/../../cutter/module/report/.libs
+export CUT_UI_FACTORY_MODULE_DIR=$BASE_DIR/../../cutter/module/ui/.libs
+
 $BASE_DIR/cutter-cairo \
     --color=auto --multi-thread -s $BASE_DIR "$@" $BASE_DIR
