@@ -45,6 +45,16 @@ text_invalid_prefix_function (void)
     test_static_function(); /* must not called! */
 }
 
+void
+initialize (void)
+{
+}
+
+void
+finalize (void)
+{
+}
+
 /*
 vi:nowrap:ai:expandtab:sw=4
 */
