@@ -1,6 +1,8 @@
-#include "cutter.h"
-#include "cut-test-case.h"
-#include "cut-runner.h"
+#include <cutter.h>
+#include <cutter/cut-test-case.h>
+#include <cutter/cut-runner.h>
+
+#include "cuttest-utils.h"
 
 void test_setup(void);
 void test_teardown(void);
@@ -14,6 +16,11 @@ void test_run_with_regex_filter(void);
 void test_run_with_name_and_regex_filter(void);
 void test_get_name(void);
 void test_start_signal(void);
+void test_success_signal(void);
+void test_failure_signal(void);
+void test_error_signal(void);
+void test_pending_signal(void);
+void test_notification_signal(void);
 void test_complete_signal(void);
 
 static CutTestCase *test_object;
@@ -26,8 +33,6 @@ static gint n_teardown = 0;
 static gint n_run_dummy_run_test_function = 0;
 static gint n_run_dummy_test_function1 = 0;
 static gint n_run_dummy_test_function2 = 0;
-static gint n_start_signal = 0;
-static gint n_complete_signal = 0;
 
 static void
 dummy_test_function1 (void)
@@ -51,6 +56,30 @@ dummy_run_test_function (void)
     n_run_dummy_run_test_function++;
 }
 
+static void
+dummy_failure_test (void)
+{
+    cut_fail("Failed!!!");
+}
+
+static void
+dummy_error_test (void)
+{
+    cut_error("Error!!!");
+}
+
+static void
+dummy_pending_test (void)
+{
+    cut_pend("Pend!!!");
+}
+
+static void
+dummy_notification_test (void)
+{
+    cut_notify("Notify!!!");
+}
+
 static void
 dummy_setup_function (void)
 {
@@ -68,7 +97,6 @@ dummy_teardown_function (void)
 void
 setup (void)
 {
-    CutTest *test;
     const gchar *test_names[] = {"/.*/", NULL};
 
     set_error_on_setup = FALSE;
@@ -78,8 +106,6 @@ setup (void)
     n_run_dummy_run_test_function = 0;
     n_run_dummy_test_function1 = 0;
     n_run_dummy_test_function2 = 0;
-    n_start_signal = 0;
-    n_complete_signal = 0;
 
     runner = cut_runner_new();
     cut_runner_set_target_test_names(runner, test_names);
@@ -90,12 +116,9 @@ setup (void)
                                     get_current_test_context,
                                     set_current_test_context,
                                     NULL, NULL);
-    test = cut_test_new("dummy_test_1", dummy_test_function1);
-    cut_test_case_add_test(test_object, test);
-    test = cut_test_new("dummy_test_2",  dummy_test_function2);
-    cut_test_case_add_test(test_object, test);
-    test = cut_test_new("run_test_function", dummy_run_test_function);
-    cut_test_case_add_test(test_object, test);
+    cuttest_add_test(test_object, "dummy_test_1", dummy_test_function1);
+    cuttest_add_test(test_object, "dummy_test_2", dummy_test_function2);
+    cuttest_add_test(test_object, "run_test_function", dummy_run_test_function);
 }
 
 void
@@ -106,15 +129,19 @@ teardown (void)
 }
 
 static void
-cb_start_signal (CutTestCase *test_case, gpointer data)
+cb_count_around_test (CutTestCase *test_case, CutTest *test,
+                      CutTestContext *test_context, gpointer data)
 {
-    n_start_signal++;
+    gint *count = data;
+    *count += 1;
 }
 
 static void
-cb_complete_signal (CutTestCase *test_case, gpointer data)
+cb_count_status (CutTest *test, CutTestContext *test_context,
+                 CutTestResult *result, gpointer data)
 {
-    n_complete_signal++;
+    gint *count = data;
+    *count += 1;
 }
 
 static gboolean
@@ -226,25 +253,97 @@ test_get_name (void)
 void
 test_start_signal (void)
 {
-    g_signal_connect(test_object, "start-test", G_CALLBACK(cb_start_signal),
-                     NULL);
+    gint n_start_tests = 0;
+    g_signal_connect(test_object, "start-test",
+                     G_CALLBACK(cb_count_around_test), &n_start_tests);
     cut_assert(cut_test_case_run(test_object, runner));
     g_signal_handlers_disconnect_by_func(test_object,
-                                         G_CALLBACK(cb_start_signal),
-                                         NULL);
-    cut_assert_equal_int(3, n_start_signal);
+                                         G_CALLBACK(cb_count_around_test),
+                                         &n_start_tests);
+    cut_assert_equal_int(3, n_start_tests);
+}
+
+void
+test_success_signal (void)
+{
+    gint n_successes = 0;
+    g_signal_connect(test_object, "success",
+                     G_CALLBACK(cb_count_status), &n_successes);
+    cut_assert(cut_test_case_run(test_object, runner));
+    g_signal_handlers_disconnect_by_func(test_object,
+                                         G_CALLBACK(cb_count_status),
+                                         &n_successes);
+    cut_assert_equal_int(1, n_successes);
+}
+
+void
+test_failure_signal (void)
+{
+    gint n_failures = 0;
+    g_signal_connect(test_object, "failure",
+                     G_CALLBACK(cb_count_status), &n_failures);
+    cuttest_add_test(test_object, "dummy_failure_test", dummy_failure_test);
+    cut_assert(!cut_test_case_run(test_object, runner));
+    g_signal_handlers_disconnect_by_func(test_object,
+                                         G_CALLBACK(cb_count_status),
+                                         &n_failures);
+    cut_assert_equal_int(1, n_failures);
+}
+
+void
+test_error_signal (void)
+{
+    gint n_errors = 0;
+    g_signal_connect(test_object, "error",
+                     G_CALLBACK(cb_count_status), &n_errors);
+    cuttest_add_test(test_object, "dummy_error_test", dummy_error_test);
+    cut_assert(!cut_test_case_run(test_object, runner));
+    g_signal_handlers_disconnect_by_func(test_object,
+                                         G_CALLBACK(cb_count_status),
+                                         &n_errors);
+    cut_assert_equal_int(1, n_errors);
+}
+
+void
+test_pending_signal (void)
+{
+    gint n_pendings = 0;
+    g_signal_connect(test_object, "pending",
+                     G_CALLBACK(cb_count_status), &n_pendings);
+    cuttest_add_test(test_object, "dummy_pending_test", dummy_pending_test);
+    cut_assert(!cut_test_case_run(test_object, runner));
+    g_signal_handlers_disconnect_by_func(test_object,
+                                         G_CALLBACK(cb_count_status),
+                                         &n_pendings);
+    cut_assert_equal_int(1, n_pendings);
+}
+
+void
+test_notification_signal (void)
+{
+    gint n_notifications = 0;
+    g_signal_connect(test_object, "notification",
+                     G_CALLBACK(cb_count_status), &n_notifications);
+    cuttest_add_test(test_object, "dummy_notification_test",
+                     dummy_notification_test);
+    cut_assert(cut_test_case_run(test_object, runner));
+    g_signal_handlers_disconnect_by_func(test_object,
+                                         G_CALLBACK(cb_count_status),
+                                         &n_notifications);
+    cut_assert_equal_int(1, n_notifications);
 }
 
 void
 test_complete_signal (void)
 {
+    gint n_complete_tests = 0;
     g_signal_connect(test_object, "complete-test",
-                     G_CALLBACK(cb_complete_signal), NULL);
+                     G_CALLBACK(cb_count_around_test), &n_complete_tests);
     cut_assert(cut_test_case_run(test_object, runner));
     g_signal_handlers_disconnect_by_func(test_object,
-                                         G_CALLBACK(cb_complete_signal),
-                                         NULL);
-    cut_assert_equal_int(3, n_complete_signal);
+                                         G_CALLBACK(cb_count_around_test),
+                                         &n_complete_tests);
+    cut_assert_equal_int(3, n_complete_tests);
 }
 
 /*
